﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Windows.Threading;

namespace BioBridgeSDK
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        List<objSDK> list = new List<objSDK>();

        public MainWindow()
        {
            InitializeComponent();

            btnDownload.IsEnabled = false;
            btnConnect.IsEnabled = true;
            btnListenEvent.IsEnabled = false;
        }

        private void btnConnect_Click(object sender, RoutedEventArgs e)
        {
            this.Cursor = Cursors.Wait;
            btnConnect.IsEnabled = false;

            if (btnConnect.Content.ToString() == "Connect")
            {
                listBox1.Items.Clear();
                list.Clear();
                ConnectDevice(txtIP.Text.Trim());
                ConnectDevice(txtIP1.Text.Trim());

                if ( list.Count > 0)
                { 
                    btnDownload.IsEnabled = true;
                    btnConnect.IsEnabled = true;
                    btnListenEvent.IsEnabled = true;
                    btnConnect.Content = "Disconnect";
                    ShowMessage(""); 
                }
                else
                {
                    btnDownload.IsEnabled = false;
                    btnConnect.IsEnabled = true;
                    btnConnect.Content = "Connect";
                }
            }
            else
            {
                ShowMessage("Disconnect Device");
                foreach (objSDK obj in list)
                {
                   obj.sdk.Disconnect(); 
                }

                list.Clear();

                btnDownload.IsEnabled = false;
                btnConnect.IsEnabled = true;
                btnListenEvent.IsEnabled = false ;
                btnConnect.Content = "Connect";
                ShowMessage("");
            }

            this.Cursor = Cursors.Arrow;
        }

        protected bool ConnectDevice(string sIP)
        {
            if (sIP == string.Empty) return false ;

            BioBridgeSDKLib.BioBridgeSDKClass sdk = new BioBridgeSDKLib.BioBridgeSDKClass();
            ShowMessage(sIP + " - Start connect device...");
            if (sdk.Connect_TCPIP("", 1, sIP, 4370, 0) == 0)
            {
                ShowMessage(sIP + " - Successfully connect device...");
                ShowMessage("");

                string sdkVer = string.Empty;
                if (sdk.GetSDKVersion(ref sdkVer, 0) == 0)
                {
                    ShowMessage(sIP + " - SDK Version: " + sdkVer);
                }
                else
                {
                    ShowMessage(sIP + " - SDK Version Error");
                }

                string firmware = string.Empty;
                if (sdk.GetFirmwareVersion(ref firmware) == 0)
                {
                    ShowMessage(sIP + " - Firmware Version: " + firmware);
                }
                else
                {
                    ShowMessage(sIP + " - Firmware Error");
                }

                int yr = 0;
                int mth = 0;
                int day_Renamed = 0;
                int hr = 0;
                int min = 0;
                int sec = 0;
                if (sdk.GetDeviceTime(ref yr, ref mth, ref day_Renamed, ref hr, ref min, ref sec) == 0)
                {
                    ShowMessage(sIP + " - Device Date and Time: " + Convert.ToString(day_Renamed) + "/" + Convert.ToString(mth) + "/" + Convert.ToString(yr) + " " + Convert.ToString(hr) + ":" + Convert.ToString(min) + ":" + Convert.ToString(sec));
                }
                else
                {
                    ShowMessage(sIP + " - !Date and Time");
                }


                ShowMessage(sIP + " - Manufacturer: " + sdk.VC);
                ShowMessage(sIP + " - Serial No: " + sdk.SN);
                ShowMessage(sIP + " - Mac Add: " + sdk.MAC);
                ShowMessage(sIP + " - Model Name: " + sdk.DC);

                if (sdk.Finger10 == 1)
                {
                    ShowMessage(sIP + " - This is a FP10 reader");
                }
                else
                {
                    ShowMessage(sIP + " - This is not a FP10 reader");
                }

                int i = 0;
                if (sdk.GetDeviceStatus(1, ref i) == 0)
                {
                    ShowMessage(sIP + " - Administrator: " + Convert.ToString(i));
                }
                if (sdk.GetDeviceStatus(2, ref i) == 0)
                {
                    ShowMessage(sIP + " - Users: " + Convert.ToString(i));
                }
                if (sdk.GetDeviceStatus(3, ref i) == 0)
                {
                    ShowMessage(sIP + " - Fingerprints: " + Convert.ToString(i));
                }
                if (sdk.GetDeviceStatus(4, ref i) == 0)
                {
                    ShowMessage(sIP + " - Passwords: " + Convert.ToString(i));
                }
                if (sdk.GetDeviceStatus(6, ref i) == 0)
                {
                    ShowMessage(sIP + " - Logs: " + Convert.ToString(i));
                }
                 
                ShowMessage("");

                list.Add(new objSDK { sdk=sdk, ipaddress=sIP  });

                return true;
            }
            else
            {
                return false;
            }
        }

        protected void ShowMessage(string msg)
        {
            listBox1.Items.Add(msg);
            listBox1.SelectedIndex = listBox1.Items.Count - 1;
            listBox1.ScrollIntoView(listBox1.Items[listBox1.Items.Count - 1]);
             
            DoEvents();
        }

        public static void DoEvents()// process messsages
        {
            Application.Current.Dispatcher.Invoke(DispatcherPriority.Background, new Action(delegate { }));
        }

        private void btnDownload_Click(object sender, RoutedEventArgs e)
        {
            foreach (objSDK  obj in list)
            {
                if (obj.sdk.IsTFT() == 0)
                {
                    string enrollNo = "";
                    int yr = 0;
                    int mth = 0;
                    int day_Renamed = 0;
                    int hr = 0;
                    int min = 0;
                    int sec = 0;
                    int ver = 0;
                    int io = 0;
                    int work = 0;
                    int iSize = 0;

                    if (obj.sdk.ReadGeneralLog(ref iSize) == 0)
                    {
                        do
                        {
                            ShowMessage((obj.ipaddress  + " - No: " + enrollNo + " Date: " + Convert.ToString(day_Renamed) + "/" + Convert.ToString(mth) + "/" + Convert.ToString(yr) + " Time: " + Convert.ToString(hr) + ":" + Convert.ToString(min) + ":" + Convert.ToString(sec) + " Verify: " + Convert.ToString(ver) + " I/O: " + Convert.ToString(io) + " Work Code: " + Convert.ToString(work)));
                        } while (obj.sdk.SSR_GetGeneralLog(ref enrollNo, ref yr, ref mth, ref day_Renamed, ref hr, ref min, ref sec, ref ver, ref io, ref work) == 0);
                    }
                }
                else
                {
                    int yr = 0;
                    int mth = 0;
                    int day_Renamed = 0;
                    int hr = 0;
                    int min = 0;
                    int sec = 0;

                    int enrollNo = 0;
                    int ver = 0;
                    int io = 0;
                    int work = 0;
                    int log = 0;

                    if (obj.sdk.ReadGeneralLog(ref log) == 0)
                    {
                        do
                        {
                            ShowMessage((obj.ipaddress + " - No: " + Convert.ToString(enrollNo) + " Date:" + Convert.ToString(day_Renamed) + "/" + Convert.ToString(mth) + "/" + Convert.ToString(yr) + " Time: " + Convert.ToString(hr) + ":" + Convert.ToString(min) + ":" + Convert.ToString(sec) + " Verify: " + Convert.ToString(ver) + " I/O: " + Convert.ToString(io) + " Work Code: " + Convert.ToString(work)));
                        } while (obj.sdk.GetGeneralLog(ref enrollNo, ref yr, ref mth, ref day_Renamed, ref hr, ref min, ref sec, ref ver, ref io, ref work) == 0);
                    }
                    else
                    {
                        ShowMessage((obj.ipaddress + " - Unable to Read General Log!!"));
                    }
                    
                }
            }
        }

        private void btnListenEvent_Click(object sender, RoutedEventArgs e)
        {
            ShowMessage("Start Listening Events...");
            RegisterEvents();
        }

        protected void RegisterEvents()
        {
            foreach (objSDK obj in list)
            {
                obj.sdk.OnAttTransactionEx += new BioBridgeSDKLib._DBioBridgeSDKEvents_OnAttTransactionExEventHandler(sdk_OnAttTransactionEx);
                //obj.sdk.OnAttTransactionEx -= new BioBridgeSDKLib._DBioBridgeSDKEvents_OnAttTransactionExEventHandler(sdk_OnAttTransactionEx);
                //obj.sdk.OnAttTransactionEx += new BioBridgeSDKLib._DBioBridgeSDKEvents_OnAttTransactionExEventHandler(sdk_OnAttTransactionEx);


            }   
        }

        //void sdk_OnAttTransactionEx(object sender,   BioBridgeSDKLib._DBioBridgeSDKEvents_OnAttTransactionExEvent e)
        //{
        //    string date = e.year + "-" + e.month + "-" + e.day + " " + e.hour + ":" + e.minute + ":" + e.second;
        //    //listBox3.Items.Add("On Transaction Event:- Date=" + date + " ,EnrollNo=" + e.enrollNo + " ,AttState=" + e.attState + " ,IsInValid=" + e.isInValid + " ,VerifyMode=" + e.verifyMode + " ,WorkCode=" + e.workCode);
        //}

         

        void sdk_OnAttTransactionEx(string EnrollNo, int IsInValid, int AttState, int VerifyMode, int Year, int Month, int Day, int Hour, int Minute, int Second, int WorkCode)
        {
            ShowMessage(("No: " + EnrollNo + " Date: " + Convert.ToString(Day) + "/" + Convert.ToString(Month) + "/" + Convert.ToString(Year) + " Time: " + Convert.ToString(Hour) + ":" + Convert.ToString(Minute) + ":" + Convert.ToString(Second) + " Verify: " + Convert.ToString(VerifyMode) + " I/O: " + Convert.ToString(AttState) + " Work Code: " + Convert.ToString(WorkCode)));
        }
    }

    public class objSDK
    {
        public BioBridgeSDKLib.BioBridgeSDKClass sdk { get; set; }
        public string ipaddress { get; set; }
    }
}
